select.l.u: Associated taxa selected by combining lower- and upper-tail...

Description Usage Arguments Value

View source: R/select.R

Description

Associated taxa selected by combining lower- and upper-tail p-values of a test using one of abundance representations.

Usage

1
select.l.u(lowerlist, upperlist, com, label)

Arguments

lowerlist

The index of selected taxa by combining lower-tail p-values.

upperlist

The index of selected taxa by combining upper-tail p-values.

com

The index of selected one-sided test after combining two one-sided community-level tests. 1: the one-sided test using lower-tail p-values. 2: the one-sided test using upper-tail p-values.

label

The lables of all non-rooted nodes.

Value

A list of selected associated taxa after combining two one-sided community-level tests:

lower

Under-presented taxa based on lower-tail p-values.

upper

Over-presented taxa based on upper-tail p-values.


songbiostat/MiAF documentation built on Feb. 18, 2022, 10:29 p.m.