Description Usage Arguments Value
Associated taxa selected by combining lower- and upper-tail p-values of a test using one of abundance representations.
1 | select.l.u(lowerlist, upperlist, com, label)
|
lowerlist |
The index of selected taxa by combining lower-tail p-values. |
upperlist |
The index of selected taxa by combining upper-tail p-values. |
com |
The index of selected one-sided test after combining two one-sided community-level tests. 1: the one-sided test using lower-tail p-values. 2: the one-sided test using upper-tail p-values. |
label |
The lables of all non-rooted nodes. |
A list of selected associated taxa after combining two one-sided community-level tests:
lower |
Under-presented taxa based on lower-tail p-values. |
upper |
Over-presented taxa based on upper-tail p-values. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.